@@ -2,18 +2,20 @@ package GIS::Distance::Formula;
 
 =head1 NAME
 
-GIS::Distance::Formula - Base class for all the GIS::Distance::Formula:: classes.
+GIS::Distance::Formula - Role for all the GIS::Distance::Formula:: classes.
 
 =head1 DESCRIPTION
 
-This class enforces an API and provides shared information for the
-formula classes that inherit from it.  Don't use this module directly.
+This role enforces an API and provides shared information for the
+formula classes that use it.
 
 =cut
 
-use Moose;
+use Moose::Role;
 use Carp qw( croak );
 
+requires 'distance';
+
 =head1 ATTRIBUTES
 
 =head2 kilometer_rho
@@ -44,21 +46,6 @@ has 'deg_ratio' => (
     default => 0.0174532925199433,
 );
 
-=head1 METHODS
-
-=head2 distance
-
-This method is just a placeholder and throws an errors if called.  The
-distance() method should be re-implemented by any class that extends
-this class.
-
-=cut
-
-sub distance {
-    my $class = __PACKAGE__;
-    croak( qq{distance() can not be called on $class directly} );
-}
-
 1;
 __END__
 
